rm(list=ls())
setwd("/Users/Sjoukje/Dropbox/@PhD Sjoukje analysis/12 juni 2018")
getwd()

if(!require("psych"))
{install.packages("psych") 
  library(psych)}
if(!require("foreign"))
{install.packages("foreign") 
  library(foreign)}
if(!require("car"))
{install.packages("car") 
  library(car)}
if(!require("corrplot"))
{install.packages("corrplot") 
  library(corrplot)}
if(!require("BaylorEdPsych"))
{install.packages("BaylorEdPsych") 
  library(BaylorEdPsych)}
if(!require("mvnmle"))
{install.packages("mvnmle") 
  library(mvnmle)}
if(!require("ggplot2"))
{install.packages("ggplot2") 
  library(ggplot2)}
if(!require("mediation"))
{install.packages("mediation") 
  library(mediation)}
if(!require("lavaan"))
{install.packages("lavaan") 
  library(lavaan)}
if(!require("semPlot"))
{install.packages("semPlot") 
  library(semPlot)}
if(!require("semTools"))
{install.packages("semTools") 
  library(semTools)}
if(!require("lme4"))
{install.packages("lme4") 
  library(lme4)}
if(!require("corpcor"))
{install.packages("corpcor") 
  library(corpcor)}
if(!require("GPArotation"))
{install.packages("GPArotation") 
  library(GPArotation)}
if(!require("plyr"))
{install.packages("plyr") 
  library(plyr)}
if(!require("reshape"))
{install.packages("reshape") 
  library(reshape)}
if(!require("cowplot"))
{install.packages("cowplot") 
  library(cowplot)}
if(!require("gdata"))
{install.packages("gdata") 
  library(gdata)}
if(!require("haven"))
{install.packages("haven") 
  library(haven)}
if(!require("nnls"))
{install.packages("nnls") 
  library(nnls)}
if(!require("Hmisc"))
{install.packages("Hmisc") 
  library(Hmisc)}

#getwd()
DataSet <- read.spss("5 Workfile_retailer_study_project3_cbonly_basicmodel2_25062018.sav", to.data.frame = TRUE, use.value.labels = FALSE)

#Checked warning message: Unrecognized record type 7, subtype 18 encountered in system file
#In stackoverflow: It does not affect the data. The record type 7 is used to store features in newer SPSS software to make older SPSS software able to read new data. But does not affect data. 
#N=456
#29 variables

#first inspection
summary(DataSet)
describe(DataSet)
str(DataSet)
#20 countries (country_WS)

#toelichting variabelen:
#Country_WS: main country the website is active in
#BP = Business Performance
#GO = Growth Orientation
#FMO = Foreign Market Orientation
#MA = Marketing activities 
#Role_comp = role in the company
#ManTeam = number of people in managementteam 
#NrEmpl = number of employees in the company
#EMDE = e-commerce market emerging / developed
#YearOS = number of years the company is selling products online
#YearOS_CB = number of years the company is selling products online across borders

#Leaving out missing values
DataSet_1 <- na.omit(DataSet)
summary(DataSet_1)
#N=453 (3 missings on number of marketingactivities and number of years online CB)

#Splitting dataset in two sets
#EMDE = 0 is countries with emerging e-commerce markets -> DS_E
#EMDE = 1 is countries with developed e-commerce markets -> DS_D

#creating separate datasets to work with 
DS_D <- subset(DataSet_1, EMDE==1)
summary(DS_D)
describe(DS_D)

DS_E <- subset(DataSet_1, EMDE==0)
summary(DS_E)
describe(DS_E)

#T-test on descriptives to see if there are sig diff between the two groups
t.test(DS_D$ManTeam, DS_E$ManTeam)
t.test(DS_D$NrEmpl, DS_E$NrEmpl)
t.test(DS_D$nr_YearsOS, DS_E$nr_YearsOS)
t.test(DS_D$nr_YearsOS_CB, DS_E$nr_YearsOS_CB)
t.test(DS_D$Age, DS_E$Age)
t.test(DS_D$Gender, DS_E$Gender)
chisq.test(DataSet_1$Role_comp, DataSet_1$EMDE)

#Calculating some descriptives
summary(DS_D$Role_comp==1)
summary(DS_D$Role_comp==2)
summary(DS_D$Role_comp==3)
summary(DS_D$Role_comp==4)
summary(DS_D$Role_comp==5)

summary(DS_D$Gender==1)
summary(DS_D$Gender==2)

summary(DS_E$Role_comp==1)
summary(DS_E$Role_comp==2)
summary(DS_E$Role_comp==3)
summary(DS_E$Role_comp==4)
summary(DS_E$Role_comp==5)

summary(DS_E$Gender==1)
summary(DS_E$Gender==2)

#step 2 EFA 
#Only testing the items GO, CO, FMO and BP in the model of retailer study 3
#Test including GO3 (reserved item) see folder 7 oktober 2018
#Item is removed
#Starting with the emerging e-commerce markets, dataset DS_E
#creating correlation matrix
corrplot(cor(DS_E[, 3:14]), order = "hclust")
#Only scales with multiple items are included
#The blue colours in the output show that there are some factors in the dataset

#criteria for factor analysis
KMO(DS_E[,3:14])
cortest.bartlett(DS_E[,3:14])
#rule of thumb: higher than .80 is excellent
#MSA per item: low for GO

#Non-identity of R: Bartlett's test
#chi-square should be significant, if non-significant all variables would be unique

#PCA
Values_PCA_E <- principal(DS_E[, 3:14], nfactors=4, rotate="none")

# screeplot
plot(Values_PCA_E$values, type ="b", main="Scree plot") 
#PCA without rotation and asking for scree plot

#Output PCA
loadings(Values_PCA_E)
summary(Values_PCA_E)
Values_PCA_E

#Check for convergent validity (all clearly loading on one factor) and discriminant validity (tems not loading on other factors) 
#Fit of the model: RMSR should be < .05 
#In the next step Varimax rotation is used to see if the outcomes show a better fit

# PCA with varimax rotation
Values_Varimax_E <- principal(DS_E[, 3:14], nfactors=4, rotate="varimax")
summary(Values_Varimax_E)
Values_Varimax_E
#Both discriminant and convergent validity good
#If using .3 as cut off point for h2 (communality) all looks good
#share variance (U2) seems good as well
#Hoffman's index are all close to 1
#Fit of the model not good: RMSR is too high (.09) (should be < .05)

#Secondly using the set of developed e-ecommerce markets, dataset DS_D
#creating correlation matrix
corrplot(cor(DS_D[, 3:14]), order = "hclust")
#Only scales with multiple items are included
#The blue colours in the output show that there are some factors in the dataset

#criteria for factor analysis
KMO(DS_D[,3:14])
cortest.bartlett(DS_D[,3:14])
#rule of thumb: higher than .80 is excellent
#RMSA per item: GO is low

#Non-identity of R: Bartlett's test
#chi-square should be significant, if non-significant all variables would be unique

#PCA
Values_PCA_D <- principal(DS_D[, 3:14], nfactors=4, rotate="none")

# screeplot
plot(Values_PCA_D$values, type ="b", main="Scree plot") 
#PCA without rotation and asking for scree plot

#Output PCA
loadings(Values_PCA_D)
summary(Values_PCA_D)
Values_PCA_D

#Check for convergent validity (all clearly loading on one factor) and discriminant validity (tems not loading on other factors) 
#Fit of the model: RMSR should be < .05 
#In the next step Varimax rotation is used to see if the outcomes show a better fit

# PCA with varimax rotation
Values_Varimax_D <- principal(DS_D[, 3:14], nfactors=4, rotate="varimax")
summary(Values_Varimax_D)
Values_Varimax_D
#Both discriminant and convergent validity good
#If using .3 as cut off point for h2 (communality) all is good 
#Hoffman's index are all close to 1 
#Fit of the model not good: RMSR is too high (.08) (should be < .05)

#PCA with varimax rotation total
Values_Varimax <- principal(DataSet_1[, 3:14], nfactors=4, rotate="varimax")
summary(Values_Varimax)
Values_Varimax

#Cronbach's alpha
attach(DataSet_1)
DataSet_1$BP <- (BP1 + BP2 + BP3 + BP5)/4
DataSet_1$GO <- (GO1 + GO2)/2
DataSet_1$FMO <- (FMO1 + FMO2 + FMO3)/3
DataSet_1$CO <- (CO1 + CO2 + CO3)/3
summary(DataSet_1)
psych::alpha(x = DataSet_1)

attach(DS_D)
DS_D$BP <- (BP1 + BP2 + BP3 + BP5)/4
DS_D$GO <- (GO1 + GO2)/2
DS_D$FMO <- (FMO1 + FMO2 + FMO3)/3
DS_D$CO <- (CO1 + CO2 + CO3)/3
summary(DS_D)
psych::alpha(x = DS_D)

attach(DS_E)
DS_E$BP <- (BP1 + BP2 + BP3 + BP5)/4
DS_E$GO <- (GO1 + GO2)/2
DS_E$FMO <- (FMO1 + FMO2 + FMO3)/3
DS_E$CO <- (CO1 + CO2 + CO3)/3
summary(DS_E)
psych::alpha(x = DS_E)

#Step 3 multigroup CFA
#create group
DataSet_1$Emarket[DataSet_1$EMDE == 0] <- "emerging"
DataSet_1$Emarket[DataSet_1$EMDE == 1] <- "developed"

#Define CFA model
CFA.model <- 'BP =~ BP1 + BP2 + BP3 + BP5 
              GO =~ GO1 + GO2
              FMO =~ FMO1 + FMO2 + FMO3
              CO =~ CO1 + CO2 + CO3'
summary(CFA.model)
fitCFA <- cfa(CFA.model, data=DataSet_1, group="Emarket")
fitCFA_total <- cfa(CFA.model, data=DataSet_1)
reliability(fitCFA_total)
summary(fitCFA)
measurementInvariance(model=CFA.model, data = DataSet_1, group = "Emarket")
fitMeasures(fitCFA, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))
modificationindices(fitCFA, sort=TRUE, minimum.value=5)
reliability(fitCFA)

fitCFA_D <- cfa(CFA.model, data=DS_D)
fitCFA_total_D <- cfa(CFA.model, data=DS_D)
reliability(fitCFA_total_D)
summary(fitCFA_D)
reliability(fitCFA_D)
fitMeasures(fitCFA_D, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))

fitCFA_E <- cfa(CFA.model, data=DS_E)
fitCFA_total_E <- cfa(CFA.model, data=DS_E)
reliability(fitCFA_total_E)
summary(fitCFA_E)
reliability(fitCFA_E)
fitMeasures(fitCFA_E, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))

#input table 2
mean(DataSet_1$BP)
sd(DataSet_1$BP)
mean(DataSet_1$GO)
sd(DataSet_1$GO)
mean(DataSet_1$CO)
sd(DataSet_1$CO)
mean(DataSet_1$FMO)
sd(DataSet_1$FMO)
mean(DataSet_1$MCA)
sd(DataSet_1$MCA)

sqrt(.72)
cor.test(GO, CO, method=c("pearson"))
cor.test(GO, FMO, method=c("pearson"))
cor.test(GO, MCA, method=c("pearson"))
cor.test(GO, BP, method=c("pearson"))

sqrt(.45)
cor.test(CO, FMO, method=c("pearson"))
cor.test(CO, MCA, method=c("pearson"))
cor.test(CO, BP, method=c("pearson"))

sqrt(.37)
cor.test(FMO, MCA, method=c("pearson"))
cor.test(FMO, BP, method=c("pearson"))

cor.test(MCA, BP, method=c("pearson"))

sqrt(.48)

#comparing model 1 to model 2 using constrain on factor loadings
fitCFA2 <- cfa(CFA.model, data=DataSet_1, group="Emarket",group.equal=c("loadings"))
summary(fitCFA2)
fitMeasures(fitCFA2, c("chisq", "df", "pvalue", "cfi", "NNFI", "rmsea", "srmr"))

anova(fitCFA,fitCFA2)
#Chisquare non-significant: measurement invariance

#step 5 SEM analysis using multigroup
full.model <- 'FMO =~ FMO1 + FMO2 + FMO3
              BP =~ BP1 + BP2 + BP3 + BP5
              GO =~ GO1 + GO2
              CO =~ CO1 + CO 2 + CO3
              # direct effect
              BP ~ c(c1, c2) * FMO
              BP ~ c(d1, d2) * GO
              BP ~ c(f1, f2) * CO
              # mediator
              MCA ~ c(a1, a2) * FMO + c(e1,e2) * GO + c(g1,g2) * CO
              BP ~ c(b1, b2) * MCA
              # indirect effect (a*b)
              indirect1 := a1 * b1
              indirect2 := a2 * b2
              indirect3 := e1 * b1
              indirect4 := e2 * b2
              indirect5 := g1 * b1
              indirect6 := g2 * b2
              #total effect
              total1 := c1 + (a1 * b1)
              total2 := c2 + (a2 * b2)
              total3 := d1 + (e1 * b1)
              total4 := d2 + (e2 * b2)
              total5 := f1 + (g1 * b1)
              total6 := f2 + (g2 * b2)
              '

#Multigroup              '
full.fit <- lavaan::sem(full.model, data=DataSet_1, group="Emarket")
summary(full.fit, rsq=TRUE)
summary(full.fit, rsq=TRUE, standardized=TRUE)
fitMeasures(full.fit, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))
modindices(full.fit, sort = TRUE, minimum.value=5)

#Check op verschil in sterkte van relaties tussen de twee groepen
full.model2 <- 'FMO =~ FMO1 + FMO2 + FMO3
                BP =~ BP1 + BP2 + BP3 + BP5
                GO =~ GO1 + GO2
                CO =~ CO1 + CO 2 + CO3
                # direct effect
                BP ~ c(c1, c2) * FMO
                BP ~ c(d1, d2) * GO
                BP ~ c(f1, f2) * CO
                # mediator
                MCA ~ c(a1, a2) * FMO + c(e1,e2) * GO + c(g1,g2) * CO
                BP ~ c(b1, b2) * MCA
                # indirect effect (a*b)
                indirect1 := a1 * b1
                indirect2 := a2 * b2
                indirect3 := e1 * b1
                indirect4 := e2 * b2
                indirect5 := g1 * b1
                indirect6 := g2 * b2
                #total effect
                total1 := c1 + (a1 * b1)
                total2 := c2 + (a2 * b2)
                total3 := d1 + (e1 * b1)
                total4 := d2 + (e2 * b2)
                total5 := f1 + (g1 * b1)
                total6 := f2 + (g2 * b2)
                #differences between standardized slopes
                #FMO -> MCA
                diff.a := a1 - a2
                #MCA -> BP
                diff.b := b1 - b2
                #FMO -> BP
                diff.c := c1 - c2
                #GO -> MCA
                diff.e := e1 - e2
                #CO -> MCA
                diff.g := g1 - g2
                '
full.fit2 <- lavaan::sem(full.model2, data=DataSet_1, group="Emarket")
summary(full.fit2, rsq=TRUE)
summary(full.fit2, rsq=TRUE, standardized=TRUE)
fitMeasures(full.fit2, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))
modindices(full.fit2, sort = TRUE, minimum.value=5)

#Total group
full.modeltotal <- 'FMO =~ FMO1 + FMO2 + FMO3
                    BP =~ BP1 + BP2 + BP3 + BP5
                    GO =~ GO1 + GO2
                    CO =~ CO1 + CO 2 + CO3
                    # direct effect
                    BP ~ c(c) * FMO
                    BP ~ c(d) * GO
                    BP ~ c(f) * CO
                    # mediator
                    MCA ~ c(a) * FMO + c(e) * GO + c(g) * CO
                    BP ~ c(b) * MCA
                    # indirect effect (a*b)
                    indirect1 := a * b
                    indirect2 := e * b
                    indirect3 := g * b
                    #total effect
                    total1 := c + (a * b)
                    total2 := d + (e * b)
                    total3 := f + (g * b)
                    '

full.fittotal <- lavaan::sem(full.modeltotal, data=DataSet_1)
summary(full.fittotal, rsq=TRUE, standardized=TRUE)
fitMeasures(full.fittotal, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))
modindices(full.fittotal, sort = TRUE, minimum.value=5)
parameterEstimates(full.fittotal, rsq=TRUE, standardized=TRUE)

full.fitgroupD <- lavaan::sem(full.modeltotal, data=DS_D)
summary(full.fitgroupD, rsq=TRUE, standardized=TRUE)
fitMeasures(full.fitgroupD, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))
modindices(full.fitgroupD, sort = TRUE, minimum.value=5)
parameterEstimates(full.fitgroupD, rsq=TRUE, standardized=TRUE)

full.fitgroupE <- lavaan::sem(full.modeltotal, data=DS_E)
summary(full.fitgroupE, rsq=TRUE, standardized=TRUE)
fitMeasures(full.fitgroupE, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))
modindices(full.fitgroupE, sort = TRUE, minimum.value=5)
parameterEstimates(full.fitgroupE, rsq=TRUE, standardized=TRUE)

#step 6 adding control variables 
full.modeltotalcontrol <- 'FMO =~ FMO1 + FMO2 + FMO3
                          BP =~ BP1 + BP2 + BP3 + BP5
                          GO =~ GO1 + GO2
                          CO =~ CO1 + CO 2 + CO3
                          # direct effect
                          BP ~ c(c) * FMO
                          BP ~ c(d) * GO
                          BP ~ c(f) * CO
                          BP ~ nr_YearsOS
                          BP ~ nr_YearsOS_CB
                          BP ~ NrEmpl
                          BP ~ GO3
                          BP ~ Age
                          MCA ~ nr_YearsOS
                          MCA ~ nr_YearsOS_CB
                          MCA ~ NrEmpl
                          MCA ~ GO3
                          MCA ~ Age
                          # mediator
                          MCA ~ c(a) * FMO + c(e) * GO + c(g) * CO
                          BP ~ c(b) * MCA
                          # indirect effect (a*b)
                          indirect1 := a * b
                          indirect2 := e * b
                          indirect3 := g * b
                          #total effect
                          total1 := c + (a * b)
                          total2 := d + (e * b)
                          total3 := f + (g * b)
                          '

fitCB.totalcontrol <- lavaan::sem(full.modeltotalcontrol, data=DataSet_1, group="Emarket")
summary(fitCB.totalcontrol, rsq=TRUE)
fitMeasures(fitCB.totalcontrol, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))

#adding control variables step-by-step
#nr employees
full.modeltotalcontrol2 <- 'FMO =~ FMO1 + FMO2 + FMO3
BP =~ BP1 + BP2 + BP3 + BP5
GO =~ GO1 + GO2
CO =~ CO1 + CO 2 + CO3
# direct effect
BP ~ c(c) * FMO
BP ~ c(d) * GO
BP ~ c(f) * CO
BP ~ NrEmpl
MCA ~ NrEmpl
# mediator
MCA ~ c(a) * FMO + c(e) * GO + c(g) * CO
BP ~ c(b) * MCA
# indirect effect (a*b)
indirect1 := a * b
indirect2 := e * b
indirect3 := g * b
#total effect
total1 := c + (a * b)
total2 := d + (e * b)
total3 := f + (g * b)
'
fitCB.totalcontrol2 <- lavaan::sem(full.modeltotalcontrol2, data=DataSet_1, group="Emarket")
summary(fitCB.totalcontrol2, rsq=TRUE, standardized=TRUE)
fitMeasures(fitCB.totalcontrol2, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))

#firm age 
full.modeltotalcontrol3 <- 'FMO =~ FMO1 + FMO2 + FMO3
                            BP =~ BP1 + BP2 + BP3 + BP5
                            GO =~ GO1 + GO2
                            CO =~ CO1 + CO 2 + CO3
                            # direct effect
                            BP ~ c(c) * FMO
                            BP ~ c(d) * GO
                            BP ~ c(f) * CO
                            BP ~ nr_YearsOS
                            MCA ~ nr_YearsOS
                            # mediator
                            MCA ~ c(a) * FMO + c(e) * GO + c(g) * CO
                            BP ~ c(b) * MCA
                            # indirect effect (a*b)
                            indirect1 := a * b
                            indirect2 := e * b
                            indirect3 := g * b
                            #total effect
                            total1 := c + (a * b)
                            total2 := d + (e * b)
                            total3 := f + (g * b)
                            '

fitCB.totalcontrol3 <- lavaan::sem(full.modeltotalcontrol3, data=DataSet_1, group="Emarket")
summary(fitCB.totalcontrol3, rsq=TRUE, standardized=TRUE)
fitMeasures(fitCB.totalcontrol3, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))

#years cross-border  
full.modeltotalcontrol4 <- 'FMO =~ FMO1 + FMO2 + FMO3
BP =~ BP1 + BP2 + BP3 + BP5
GO =~ GO1 + GO2
CO =~ CO1 + CO 2 + CO3
# direct effect
BP ~ c(c) * FMO
BP ~ c(d) * GO
BP ~ c(f) * CO
BP ~ nr_YearsOS_CB
MCA ~ nr_YearsOS_CB
# mediator
MCA ~ c(a) * FMO + c(e) * GO + c(g) * CO
BP ~ c(b) * MCA
# indirect effect (a*b)
indirect1 := a * b
indirect2 := e * b
indirect3 := g * b
#total effect
total1 := c + (a * b)
total2 := d + (e * b)
total3 := f + (g * b)
'

fitCB.totalcontrol4 <- lavaan::sem(full.modeltotalcontrol4, data=DataSet_1, group="Emarket")
summary(fitCB.totalcontrol4, rsq=TRUE, standardized=TRUE)
fitMeasures(fitCB.totalcontrol4, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))

#years cross-border  
full.modeltotalcontrol5 <- 'FMO =~ FMO1 + FMO2 + FMO3
BP =~ BP1 + BP2 + BP3 + BP5
GO =~ GO1 + GO2
CO =~ CO1 + CO 2 + CO3
# direct effect
BP ~ c(c) * FMO
BP ~ c(d) * GO
BP ~ c(f) * CO
BP ~ ManTeam
MCA ~ ManTeam
# mediator
MCA ~ c(a) * FMO + c(e) * GO + c(g) * CO
BP ~ c(b) * MCA
# indirect effect (a*b)
indirect1 := a * b
indirect2 := e * b
indirect3 := g * b
#total effect
total1 := c + (a * b)
total2 := d + (e * b)
total3 := f + (g * b)
'

fitCB.totalcontrol5 <- lavaan::sem(full.modeltotalcontrol5, data=DataSet_1, group="Emarket")
summary(fitCB.totalcontrol5, rsq=TRUE, standardized=TRUE)
fitMeasures(fitCB.totalcontrol5, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))

#controlling for age 
full.modeltotalcontrol6 <- 'FMO =~ FMO1 + FMO2 + FMO3
BP =~ BP1 + BP2 + BP3 + BP5
GO =~ GO1 + GO2
CO =~ CO1 + CO 2 + CO3
# direct effect
BP ~ c(c) * FMO
BP ~ c(d) * GO
BP ~ c(f) * CO
BP ~ Age
MCA ~ Age
# mediator
MCA ~ c(a) * FMO + c(e) * GO + c(g) * CO
BP ~ c(b) * MCA
# indirect effect (a*b)
indirect1 := a * b
indirect2 := e * b
indirect3 := g * b
#total effect
total1 := c + (a * b)
total2 := d + (e * b)
total3 := f + (g * b)
'

fitCB.totalcontrol6 <- lavaan::sem(full.modeltotalcontrol6, data=DataSet_1, group="Emarket")
summary(fitCB.totalcontrol6, rsq=TRUE, standardized=TRUE)
fitMeasures(fitCB.totalcontrol6, c("chisq", "df", "pvalue", "CFI", "NNFI", "SRMR", "RMSEA"))

#Percentages digital marketing activities
count(DS_D$MCA2)
count(DS_D$MCA3)
count(DS_D$MCA4)
count(DS_D$MCA5)
count(DS_D$MCA6)
count(DS_D$MCA7)
count(DS_D$MCA8)
count(DS_D$MCA9)

count(DS_E$MCA2)
count(DS_E$MCA3)
count(DS_E$MCA4)
count(DS_E$MCA5)
count(DS_E$MCA6)
count(DS_E$MCA7)
count(DS_E$MCA8)
count(DS_E$MCA9)
